@@ -1,17 +1,16 @@
 import logging
 import os
-from urllib.parse import urlparse
 
-from taggit.models import Tag
 from django.conf import settings
 from django.core.handlers.base import BaseHandler
 from django.test.client import RequestFactory
-from wagtail.core.models import Page, Site
+from wagtail.core.models import Page
 
+from webspace.loader import get_model
 from webspace.cms.bakery.views import BuildableDetailView
 from webspace.cms.bakery.abstract import WagtailPageBakeryModel
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('bakery')
 
 USER_AGENT_DESKTOP = "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.129 Safari/537.36"
 USER_AGENT_MOBILE = "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1"
@@ -40,53 +39,44 @@ class WagtailBakeryView(BuildableDetailView):
 
     def get_build_path(self, obj):
         url = self.get_url(obj)
-        if url.startswith('http'):
-            url_parsed = urlparse(url)
-            path = url_parsed.path
-            hostname = url_parsed.hostname
-            if getattr(settings, 'BAKERY_MULTISITE', False):
-                build_path = os.path.join(
-                    settings.BUILD_DIR, hostname, path[1:])
-            else:
-                build_path = os.path.join(settings.BUILD_DIR, path[1:])
-        else:
-            build_path = os.path.join(settings.BUILD_DIR, url[1:])
+        site = self.get_site(obj)
+        build_path = os.path.join(settings.BUILD_DIR, site.hostname, url[1:])
         os.path.exists(build_path) or os.makedirs(build_path)
         return os.path.join(build_path, 'index.html')
 
     def get_url(self, obj):
-        return obj.specific.url
+        return obj.relative_url(self.get_site(obj))
 
     def get_path(self, obj):
         return obj.path
 
     def build_object(self, obj):
-        site = Site.objects.all().first()
         logger.debug("Building %s" % obj)
 
-        self.build_object_env(site, obj)
-        self.build_object_env(site, obj, mobile=True)
-        self.build_object_env(site, obj, amp=True)
-        self.build_object_env(site, obj, mobile=True, amp=True)
+        self.build_object_env(obj)
+        self.build_object_env(obj, mobile=True)
+        self.build_object_env(obj, amp=True)
+        self.build_object_env(obj, mobile=True, amp=True)
 
-    def build_object_env(self, site, obj, amp=False, mobile=False):
-        user_agent = USER_AGENT_MOBILE if mobile else USER_AGENT_DESKTOP
-        pre_url = '/amp' if amp else ''
-        self.request = RequestFactory(
-            SERVER_NAME=site.hostname,
-            SERVER_PORT=str(site.port)
-        ).get(
-            pre_url + self.get_url(obj) + '?build=true',
-            HTTP_USER_AGENT=user_agent
-        )
-        self.set_kwargs(obj)
-        path = self.get_build_path(obj)
-        if mobile:
-            path = path.replace('.html', '-mobile.html')
-        if amp:
-            path = path.replace('.html', '-amp.html')
-        self.build_file(path, self.get_content(obj))
-        print(path + ' : OK')
+    def build_object_env(self, obj, amp=False, mobile=False):
+        # Fix create page root
+        if self.get_url(obj):
+            site = self.get_site(obj)
+            user_agent = USER_AGENT_MOBILE if mobile else USER_AGENT_DESKTOP
+            pre_url = '/amp' if amp else ''
+            url = pre_url + self.get_url(obj) + '?build=true'
+            logger.debug("Building %s:%s" % (site.hostname, str(site.port) + url))
+            self.request = RequestFactory(
+                SERVER_NAME=site.hostname,
+                SERVER_PORT=str(site.port)
+            ).get(url, HTTP_USER_AGENT=user_agent)
+            self.set_kwargs(obj)
+            path = self.get_build_path(obj)
+            if mobile:
+                path = path.replace('.html', '-mobile.html')
+            if amp:
+                path = path.replace('.html', '-amp.html')
+            self.build_file(path, self.get_content(obj))
 
     def build_queryset(self):
         for item in self.get_queryset().all():
@@ -94,6 +84,9 @@ class WagtailBakeryView(BuildableDetailView):
             if url is not None:
                 self.build_object(item)
 
+    def get_site(self, obj):
+        return obj.get_site()
+
     class Meta:
         abstract = True
 
@@ -109,8 +102,17 @@ class AllBuildablePagesView(WagtailBakeryView):
 
 class BlogIndexTagPagesView(WagtailBakeryView):
 
+    def get_site(self, obj):
+        return obj.content_object.get_site()
+
     def get_url(self, obj):
-        return '/articles/tags/%s' % obj.slug + '/'
+        BlogIndexPage = get_model('cms', 'BlogIndexPage')
+        site = obj.content_object.get_site()
+        index_blog = BlogIndexPage.objects.in_site(site).first()
+        blog_index_url = index_blog.relative_url(site)
+
+        return '%s' % blog_index_url + 'tags/%s' % obj.tag.slug + '/'
 
     def get_queryset(self):
-        return Tag.objects.all()
+        BlogPageTag = get_model('cms', 'BlogPageTag')
+        return BlogPageTag.objects.all()
