@@ -30,12 +30,17 @@ TableEntry = get_class('cms.blocks.entries', 'TableEntry')
 AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
 NumbersEntry = get_class('cms.blocks.entries', 'NumbersEntry')
 FormEntry = get_class('cms.blocks.entries', 'FormEntry')
+SocialLinks = get_class('cms.blocks.static', 'SocialLinks')
+SocialShare = get_class('cms.blocks.static', 'SocialShare')
+
 
 # Models
 MenuItem = get_model('cms', 'MenuItem')
 Menu = get_model('cms', 'Menu')
 IconSnippet = get_model('cms', 'IconSnippet')
 Navigation = get_model('cms', 'Navigation')
+Person = get_model('cms', 'Person')
+
 
 HomePage = get_model('cms', 'HomePage')
 ContentPage = get_model('cms', 'ContentPage')
@@ -68,6 +73,7 @@ class Command(BaseCommand):
         Navigation.objects.all().delete()
         Form.objects.all().delete()
         FormField.objects.all().delete()
+        Person.objects.all().delete()
 
         article_entry = ArticlesEntry()
         buttons_entry = ButtonsEntry()
@@ -86,6 +92,9 @@ class Command(BaseCommand):
         numbers_entry = NumbersEntry()
         form_entry = FormEntry()
 
+        social_links = SocialLinks()
+        social_share = SocialShare()
+
         mocker = Mocker()
 
         # Create page content type
@@ -207,7 +216,7 @@ class Command(BaseCommand):
                     embed_entry.mock(container='content', theme=constants.THEME_LIGHT),
                     text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                 ]),
-                author=get_test_account(),
+                author=mocker.get_person(),
                 bg_desktop=json.dumps([{
                     'type': ('svg' if i % 2 else 'image'),
                     'value': mocker.file(file_desktop).id
@@ -554,6 +563,25 @@ class Command(BaseCommand):
         mocker.menu(forms_page, block_menu_id)
         mocker.add_menu(forms_page, home_page_menu_id)
 
+        # -------------------------------- Social Media --------------------------------
+
+        forms_page = ContentPage(
+            title="Social Media",
+            slug='social-media',
+            body=json.dumps([
+                text_entry.mock(txt='<h1>Social Media</h1>', align='center'),
+                social_links.mock(),
+                social_links.mock(theme=constants.THEME_SPACE_INVERSE),
+                social_links.mock(theme=constants.THEME_LIGHT),
+                social_share.mock(),
+                social_share.mock(theme=constants.THEME_SPACE_INVERSE),
+                social_share.mock(theme=constants.THEME_LIGHT),
+            ])
+        )
+        block_page.add_child(instance=forms_page)
+        mocker.menu(forms_page, block_menu_id)
+        mocker.add_menu(forms_page, home_page_menu_id)
+
         # -------------------------------- Settings --------------------------------
 
         ws_settings = WebspaceSettings.for_site(site)
@@ -570,6 +598,12 @@ class Command(BaseCommand):
         ws_settings.language = 'fr'
         ws_settings.collect_text = "<p>En poursuivant votre navigation sur ce site, vous acceptez nos CGU ainsi que notre Politique de confidentialité</p>"
         ws_settings.social_share_text = """
+        <h2>Partager cette page!</h2>
+        <hr>
+        <p>Chaque semaine dans votre boite mail, un condensé de conseils et de nouvelles entreprises qui
+            recrutent.</p>
+        """
+        ws_settings.social_links_text = """
         <h2>Suivez-nous!</h2>
         <hr>
         <p>Chaque semaine dans votre boite mail, un condensé de conseils et de nouvelles entreprises qui
