@@ -9,6 +9,7 @@ from django.conf import settings
 from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 from django.http import Http404
 from django.template.response import TemplateResponse
+from django.http import HttpResponse
 
 from wagtail.admin.edit_handlers import FieldPanel
 from wagtail.core.url_routing import RouteResult
@@ -28,7 +29,7 @@ from webspace.cms.bakery.abstract import WagtailPageBakeryModel
 from webspace.cms import constants
 from webspace.cms.amp.mixins import AmpMixin
 from webspace.cms.forms.abstract import FormMixin
-
+from webspace.cms.amp.utils import amp_mode_active
 from webspace.loader import get_model, get_class
 
 GenericPage = get_model('cms', 'GenericPage')
@@ -228,7 +229,16 @@ class ABlogIndexPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
                 self.get_context(request, kwargs['tag'])
             )
         else:
-            return self.render_baked_file(
-                request,
-                settings.TEMPLATE_PATH + "/build" + self.get_url() + 'tags/' + kwargs['tag'].slug + '/'
-            )
+            site = self.get_site()
+            path_file = self.relative_url(site)
+            index = 'index.html' if request.user_agent.is_pc else 'index-mobile.html'
+            if amp_mode_active():
+                index = index.replace('.html', '-amp.html')
+                path_file = path_file.replace('/amp', '')
+            with open(settings.BUILD_DIR + '/' + site.hostname + '/' + path_file + 'tags/' + kwargs[
+                'tag'].slug + '/' + index, "rb") as fd:
+                compressed = fd.read()
+                response = HttpResponse(compressed)
+                response['Content-Encoding'] = 'gzip'
+                response['Content-Length'] = str(len(compressed))
+                return response
