@@ -74,6 +74,12 @@ def cached_form(form, request):
     return []
 
 
+def debug(item):
+    import pdb
+    pdb.set_trace()
+    return
+
+
 register.filter('ico', ico)
 register.filter('ico_astro', ico_astro)
 register.filter('ico_get', ico_get)
@@ -82,3 +88,4 @@ register.filter('embed', embed)
 register.filter('strfix', strfix)
 register.filter('klass', klass)
 register.filter('cached_form', cached_form)
+register.filter('debug', debug)
